pub struct TextParams<'a> {
pub text: &'a str,
pub position: Vector2<f64>,
pub anchor: TextAnchor,
pub area_width: Option<f32>,
pub area_height: Option<f32>,
pub font_size: f32,
pub line_height: f32,
pub color: LinSrgb,
pub attrs: Attrs<'a>,
}Expand description
Parameters for displaying text.
Fields
text: &'a strContent of the text to be displayed. Default: “”.
position: Vector2<f64>Position of the anchor point in simulation space. Default: origin.
anchor: TextAnchorPlacement of the anchor point relative to the text. Default: center.
area_width: Option<f32>Fixed width for the text area in pixels. Default: None. If not given, the text is laid out based on its own dimensions.
area_height: Option<f32>Fixed height for the text area in pixels. Default: None. If not given, the text is laid out based on its own dimensions.
font_size: f32Font size of the text. Default: 30.
line_height: f32Line height of the text. Default: 42.
color: LinSrgbColor of the text. Default: black.
attrs: Attrs<'a>Set of cosmic-text attributes for the text buffer.
Default: default_text_attrs.
Types for the fields can be accessed through the library’s re-export of glyphon.